package javax.swing;

import java.io.Serializable;

public class SpinnerNumberModel extends AbstractSpinnerModel implements Serializable
{
    private Number stepSize;
    private Number value;
    private Comparable minimum;
    private Comparable maximum;
    
    public SpinnerNumberModel(Number value, Comparable minimum, Comparable maximum, Number stepSize) {
        if (value == null || stepSize == null) {
            throw new IllegalArgumentException("value and stepSize must be non-null");
        }
        if ((minimum != null && minimum.compareTo(value) > 0) || (maximum != null && maximum.compareTo(value) < 0)) {
            throw new IllegalArgumentException("(minimum <= value <= maximum) is false");
        }
        this.value = value;
        this.minimum = minimum;
        this.maximum = maximum;
        this.stepSize = stepSize;
        return;
    }
    
    public SpinnerNumberModel(int i, int j, int k, int l) {
        this(Integer.valueOf(i), Integer.valueOf(j), Integer.valueOf(k), Integer.valueOf(l));
    }
    
    public SpinnerNumberModel(double value, double value2, double value3, double value4) {
        this(new Double(value), new Double(value2), new Double(value3), new Double(value4));
    }
    
    public SpinnerNumberModel() {
        this(Integer.valueOf(0), null, null, Integer.valueOf(1));
    }
    
    public void setMinimum(Comparable minimum) {
        if (!((minimum != null) ? minimum.equals(this.minimum) : (this.minimum == null))) {
            this.minimum = minimum;
            this.fireStateChanged();
        }
    }
    
    public Comparable getMinimum() {
        return this.minimum;
    }
    
    public void setMaximum(Comparable maximum) {
        if (!((maximum != null) ? maximum.equals(this.maximum) : (this.maximum == null))) {
            this.maximum = maximum;
            this.fireStateChanged();
        }
    }
    
    public Comparable getMaximum() {
        return this.maximum;
    }
    
    public void setStepSize(Number stepSize) {
        if (stepSize == null) {
            throw new IllegalArgumentException("null stepSize");
        }
        if (!stepSize.equals(this.stepSize)) {
            this.stepSize = stepSize;
            this.fireStateChanged();
        }
        return;
    }
    
    public Number getStepSize() {
        return this.stepSize;
    }
    
    private Number incrValue(int n) {
        Double n2;
        if (this.value instanceof Float || this.value instanceof Double) {
            double n3 = this.value.doubleValue() + this.stepSize.doubleValue() * (double)n;
            if ((this.value instanceof Double)) {
                n2 = new Double(n3);
            }
            else {
                n2 = new Float(n3);
            }
        }
        else {
            long l = this.value.longValue() + this.stepSize.longValue() * (long)n;
            if ((this.value instanceof Long)) {
                n2 = Long.valueOf(l);
            }
            else if ((this.value instanceof Integer)) {
                n2 = Integer.valueOf((int)l);
            }
            else if ((this.value instanceof Short)) {
                n2 = Short.valueOf((short)(int)l);
            }
            else {
                n2 = Byte.valueOf((byte)(int)l);
            }
        }
        if (this.maximum != null && this.maximum.compareTo(n2) < 0) {
            return null;
        }
        if (this.minimum != null && this.minimum.compareTo(n2) > 0) {
            return null;
        }
        return n2;
    }
    
    @Override
    public Object getNextValue() {
        return this.incrValue(1);
    }
    
    @Override
    public Object getPreviousValue() {
        return this.incrValue(-1);
    }
    
    public Number getNumber() {
        return this.value;
    }
    
    @Override
    public Object getValue() {
        return this.value;
    }
    
    @Override
    public void setValue(Object o) {
        if (o == null || !(o instanceof Number)) {
            throw new IllegalArgumentException("illegal value");
        }
        if (!o.equals(this.value)) {
            this.value = (Number)o;
            this.fireStateChanged();
        }
        return;
    }
}
